VideoTrackChanged class
A video track appeared or went away for identity (subscribe/unsubscribe); views listening for this identity should rebuild.
- Inheritance
-
- Object
- VoxaTransportEvent
- VideoTrackChanged
Constructors
- VideoTrackChanged(String? identity)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited